pub struct InteractionEvent {
pub full_id: String,
pub protocol: String,
pub unique_id: String,
pub timestamp: String,
pub raw_request: Option<String>,
pub raw_response: Option<String>,
}Expand description
A raw interaction event returned by the interactsh service.
Thread Safety
InteractionEvent is Send and Sync.
Fields
full_id: Stringprotocol: Stringunique_id: Stringtimestamp: Stringraw_request: Option<String>raw_response: Option<String>Trait Implementations
Sourceimpl Clone for InteractionEvent
impl Clone for InteractionEvent
Sourcefn clone(&self) -> InteractionEvent
fn clone(&self) -> InteractionEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InteractionEvent
impl Debug for InteractionEvent
Sourceimpl Default for InteractionEvent
impl Default for InteractionEvent
Sourcefn default() -> InteractionEvent
fn default() -> InteractionEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InteractionEvent
impl<'de> Deserialize<'de> for InteractionEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InteractionEvent
impl Display for InteractionEvent
impl Eq for InteractionEvent
Sourceimpl PartialEq for InteractionEvent
impl PartialEq for InteractionEvent
Sourcefn eq(&self, other: &InteractionEvent) -> bool
fn eq(&self, other: &InteractionEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InteractionEvent
impl Serialize for InteractionEvent
impl StructuralPartialEq for InteractionEvent